@@ -91,8 +91,8 @@ sub _header_to_string {
   $info->{version}     ||= '0.01';
 
   $str .= sprintf "=head1 NAME\n\n%s\n\n",             $info->{title};
-  $str .= sprintf "=head1 DESCRIPTION\n\n%s\n\n",      $info->{description};
   $str .= sprintf "=head1 VERSION\n\n%s\n\n",          $info->{version};
+  $str .= sprintf "=head1 DESCRIPTION\n\n%s\n\n",      $info->{description};
   $str .= sprintf "=head1 TERMS OF SERVICE\n\n%s\n\n", $info->{termsOfService} if $info->{termsOfService};
   $str;
 }
@@ -122,7 +122,7 @@ sub _path_response_to_string {
   for my $code (sort keys %$responses) {
     my $res = $responses->{$code};
     $str .= sprintf "=head3 %s\n\n", _status_code_to_string($code);
-    $str .= sprintf "%s\n\n", $res->{description} || NO_DESCRIPTION;
+    $str .= $self->_summary_and_description($res);
     $str .= $self->_schema_to_string_dispatch($res->{schema}, 0) . "\n";
   }
 
@@ -147,7 +147,7 @@ PATH:
 
       $str .= sprintf "=head2 %s\n\n", $info->{operationId} || join(' ', uc $method, $path);
       $str .= "  THIS RESOURCE IS DEPRECATED!\n\n" if $info->{deprecated};
-      $str .= sprintf "%s\n\n", $info->{description} || $info->{summary} || NO_DESCRIPTION;
+      $str .= $self->_summary_and_description($info);
       $str .= sprintf "See also L<%s>\n\n", $ext->{url} if $ext;
 
       next METHOD if $info->{deprecated};
@@ -237,6 +237,16 @@ sub _schema_to_string_dispatch {
   $self->$method($schema, $depth);
 }
 
+sub _summary_and_description {
+  my ($self, $data) = @_;
+  my $str = '';
+
+  $str .= "$data->{summary}\n\n"     if $data->{summary};
+  $str .= "$data->{description}\n\n" if $data->{description};
+  $str .= NO_DESCRIPTION . "\n\n" unless $data->{summary} or $data->{description};
+  $str;
+}
+
 # FUNCTIONS
 sub _ascii_table {
   my ($rows, $pad) = @_;
